[Intel-gfx] [PATCH] CHROMIUM: drm/i915: Increase the wakeup up delay for PPT

james.ausmus at intel.com james.ausmus at intel.com
Fri Aug 16 02:31:08 CEST 2013


From: Stéphane Marchesin <marcheu at chromium.org>

This is basically increasing the delay added by commit:

commit 1d20c4fb51f18461f385ab7f039f695d37b15958
Author: Stéphane Marchesin <marcheu at chromium.org>
Date:   Wed Jun 26 15:17:11 2013 -0700

    CHROMIUM: drm/i915: Work around PPT chipsets wakeup delays

As it seems the previous delay wasn't enough.

BUG=chrome-os-partner:21306
TEST=still works on parrot, but couldn't repro the original bug

Change-Id: I08d79f41ce1ddf0b6bcd0c620f19f7eb6dbe86c0
Reviewed-on: https://gerrit.chromium.org/gerrit/63399
Tested-by: Stéphane Marchesin <marcheu at chromium.org>
Reviewed-by: Sonny Rao <sonnyrao at chromium.org>
Commit-Queue: Mohammed Habibulla <moch at chromium.org>
Reviewed-by: Mohammed Habibulla <moch at chromium.org>
---
 drivers/gpu/drm/i915/intel_display.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/gpu/drm/i915/intel_display.c b/drivers/gpu/drm/i915/intel_display.c
index c933bfa..d13e3a9 100644
--- a/drivers/gpu/drm/i915/intel_display.c
+++ b/drivers/gpu/drm/i915/intel_display.c
@@ -4837,10 +4837,10 @@ static void ironlake_init_pch_refclk(struct drm_device *dev)
 	/*
 	 * On resume, the PPT PCH doesn't seem to work right away, and
 	 * sometimes ignores register read/writes until it's completely up.
 	 * Waiting 30ms seems to be long enough to avoid this.
 	 */
 	if (dev_priv->pch_id == INTEL_PCH_PPT_DEVICE_ID_TYPE)
-		msleep(30);
+		msleep(60);
 
 }
 
@@ -4837,10 +4837,10 @@ static void ironlake_init_pch_refclk(struct drm_device *dev)
 	 * On resume, the PPT PCH doesn't seem to work right away, and
 	 * sometimes ignores register read/writes until it's completely up.
-	 * Waiting 30ms seems to be long enough to avoid this.
+	 * Waiting 60ms seems to be long enough to avoid this.
 	 */
 	if (dev_priv->pch_id == INTEL_PCH_PPT_DEVICE_ID_TYPE)
-- 
1.8.3.2




More information about the Intel-gfx mailing list